MCMCcopies.cl simulates in parallel
nmc iid copies of the MCMC algorithm passed in the list mcmc_algo,
for n (time) iterations, and returns an object of class plMCMC holding an array of the trajectories and running information.
About parallel computing:
The Rmpi option is less efficient than the default option
using parallel if you are running on a single computer.
MPI communication are required only for running on a true cluster/grid.
This generic cluster version implementing
several types of cluster for running on a single, multicore computer
or on a true cluster using MPI communications may not
work on all platform/OS. For instance the parallel socket cluster version
does not work on Windows machines (see the parallel package documentation).
About passing your MCMC algorithm:
The list mcmc_algo must contain the named elements:
name, the name of the MCMC, such as "RWHM"
chain, the function for simulation of n steps of a single chain
step, the function for simulation of 1 step of that algorithm
q_pdf, the density of the proposal
q_proposal, the function that simulates a proposal
For examples, see the algorithms currently implemented:
RWHM, the Random Walk Hasting-Metropolis with gaussian proposal;
HMIS_norm, an Independence Sampler HM with gaussian proposal;
AMHaario, the Adaptive-Metropolis (AM) from Haario (2001);
IID_norm, a gaussian iid sampler which is merely
a "fake" MCMC for testing purposes.